Struct Repeat
pub struct Repeat {
byte: u8,
}Expand description
An async reader which yields one byte over and over and over and over and over and…
This struct is generally created by calling repeat. Please
see the documentation of repeat() for more details.
This is an asynchronous version of std::io::Repeat.
Fields
byte: u8Trait Implementations